import type { Options } from "@/options";
import type { InjectionKey } from "vue";
/**
 * The main entry point for interacting with service-level (non-UI) functionality.
 * Access the service methods using [Vue3 injection](https://vuejs.org/guide/components/provide-inject.html)
 * with the key `"Tiki"`
 *
 * @example
 * ```
 * <script setup lang="ts">
 * const tiki: TikiService | undefined = inject("Tiki");
 * </script>
 * ```
 */
export declare class TikiService {
    private readonly config;
    private readonly capture;
    private readonly store;
    private readonly internalHandlers;
    private readonly publish;
    private _isInitialized;
    /**
     * Do not construct directly. Use [Vue injection](https://vuejs.org/guide/components/provide-inject.html)
     * to access the singleton registered with the key "Tiki"
     *
     * @example
     * const tiki: TikiService | undefined = inject("Tiki");
     */
    constructor(options: Options);
    /**
     * Get the initialization status of the service.
     * @returns `true` if the service is initialized, `false` otherwise.
     */
    get isInitialized(): boolean;
    /**
     * Initialize the service for a specified user.
     * @param id - The user's unique identifier.
     * @returns A Promise that resolves when the initialization is complete.
     */
    initialize(id: string): Promise<void>;
    /**
     * Log the user out of all linked accounts, remove all credentials,
     * clear stored preferences, and in-memory service cache.
     * @returns A Promise that resolves when the logout is complete.
     */
    logout(): Promise<void>;
    checkLogin(loginType: "GMAIL" | "RETAILER"): void;
    checkLogout(): void;
    checkInitialize(hasGmail: boolean, hasRetailer: boolean): Promise<void>;
    /**
     * @ignore
     */
    inject(provide: (key: InjectionKey<unknown> | string | number, value: unknown) => void): void;
}
